<?php

namespace Drupal\Tests\recently_read\Functional;

use Drupal\recently_read\Entity\RecentlyRead;
use PHPUnit\Framework\Attributes\Group;

/**
 * Test record deletion that is happening on cron.
 */
#[Group('recently_read')]
final class CronRecordDeletionTest extends RecentlyReadTestBase {

  /**
   * Test deletion of entries that are older than configured time.
   */
  public function testTimeBasedDeletion(): void {
    // Mock recently read records.
    $this->config('recently_read.configuration')
      ->set('delete_config', 'time')
      ->set('delete_time', '-1 hour')
      ->save();

    for ($i = 1; $i <= 6; $i++) {
      $created = strtotime('-30 minutes');
      if ($i % 2 == 1) {
        $created = strtotime('-2 hours');
      }

      RecentlyRead::create([
        'type' => 'node',
        'user_id' => $this->user->id(),
        'entity_id' => $i,
        'created' => $created,
      ])->save();
    }

    $this->container->get('cron')->run();

    $records = $this->container->get('entity_type.manager')
      ->getStorage('recently_read')
      ->loadMultiple();

    $this->assertCount(3, $records);
  }

  /**
   * Test that records of anonymous users get deleted after a specific time.
   */
  public function testCountConfigurationDeletion(): void {
    $this->config('recently_read.configuration')
      ->set('delete_config', 'count')
      ->set('delete_time_anon', '-1 hour')
      ->save();

    for ($i = 1; $i <= 6; $i++) {
      $created = strtotime('-30 minutes');
      if ($i % 2 == 1) {
        $created = strtotime('-2 hours');
      }

      RecentlyRead::create([
        'type' => 'node',
        'user_id' => 0,
        'entity_id' => $i,
        'created' => $created,
      ])->save();
    }

    $this->container->get('cron')->run();

    $records = $this->container->get('entity_type.manager')
      ->getStorage('recently_read')
      ->loadByProperties(['user_id' => 0]);

    $this->assertCount(3, $records);
  }

}
