<?php

namespace Drupal\Tests\recently_read\Functional;

use Drupal\Core\Url;
use Drupal\node\NodeInterface;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\node\Traits\NodeCreationTrait;
use Drupal\user\Entity\User;

/**
 * Testing Recently Read Display Mode.
 *
 * @group block
 * @group recently_read
 */
class RecentlyReadDisplayModeTest extends BrowserTestBase {

  use NodeCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'node',
    'block',
    'user',
    'recently_read',
    'views',
    'taxonomy',
  ];

  /**
   * User object.
   *
   * @var \Drupal\user\Entity\User
   */
  private User $user;

  /**
   * Initial set up for test.
   */
  protected function setUp(): void {
    // Always call the parent setUp().
    parent::setUp();
    $this->drupalCreateContentType(['type' => 'foo']);

    $this->config('recently_read.recently_read_type.node')
      ->set('types', ['foo'])
      ->set('view_modes', ['teaser'])
      ->save();

    $this->drupalPlaceBlock(
      'views_block:recently_read_content-block_1',
      [
        'id' => 'recently_read_content',
        'items_per_page' => 4,
      ]
    );
  }

  /**
   * Test recently read block with different display modes.
   */
  public function testBlockWithDifferentDisplayModes() {
    $user = $this->DrupalCreateUser(['access content']);
    $this->drupalGet(Url::fromRoute('user.login'));
    $this->submitForm([
      'name' => $user->getAccountName(),
      'pass' => $user->passRaw,
    ], 'Log in');

    $node1 = $this->recentlyReadNodeCreate([
      'title' => 'Node 1',
      'type' => 'foo',
    ]);
    $node2 = $this->recentlyReadNodeCreate([
      'title' => 'Node 2',
      'type' => 'foo',
    ]);
    $node3 = $this->recentlyReadNodeCreate([
      'title' => 'Node 3',
      'type' => 'foo',
    ]);

    // Get nodes in full view mode.
    $this->drupalGet($node1->toUrl());
    $this->drupalGet($node2->toUrl());
    $this->drupalGet($node3->toUrl());

    // Assert that recently read block is empty.
    $session = $this->assertSession();
    $session->linkNotExists('Node 1');
    $session->linkNotExists('Node 2');
    $session->linkNotExists('Node 3');

    // Get nodes in teaser view mode.
    $this->drupalGet('/node');

    // Assert that recently read block is not empty.
    $session = $this->assertSession();
    $session->linkExists('Node 1');
    $session->linkExists('Node 2');
    $session->linkExists('Node 3');
  }

  /**
   * Helper method for creating nodes.
   *
   * @param array $settings
   *   Settings for node creation.
   *
   * @return \Drupal\node\NodeInterface|null
   *   The created node.
   */
  protected function recentlyReadNodeCreate(array $settings): ?NodeInterface {
    $this->drupalCreateNode($settings);
    if (isset($settings['title'])) {
      return $this->drupalGetNodeByTitle($settings['title']);
    }
    return NULL;
  }

}
