<?php

namespace Drupal\Tests\recently_read\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\node\Traits\NodeCreationTrait;
use Drupal\user\UserInterface;

/**
 * Provides a base testing class for api service.
 */
abstract class RecentlyReadTestBase extends BrowserTestBase {

  use NodeCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'user',
    'recently_read',
  ];

  /**
   * Array of nodes used in tests.
   *
   * @var array<\Drupal\node\NodeInterface>
   */
  protected array $nodes;

  /**
   * User account used in tests.
   *
   * @var \Drupal\User\UserInterface
   */
  protected UserInterface $user;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Create content types used for testing.
    $this->drupalCreateContentType(['type' => 'foo']);
    $this->drupalCreateContentType(['type' => 'bar']);
    $this->drupalCreateContentType(['type' => 'baz']);

    // Setup module config for node.
    $this->config('recently_read.recently_read_type.node')
      ->set('types', ['foo', 'baz'])
      ->save();

    $this->nodes = [
      $this->drupalCreateNode(['type' => 'foo', 'title' => 'Test Node Foo 1']),
      $this->drupalCreateNode(['type' => 'foo', 'title' => 'Test Node Foo 2']),
      $this->drupalCreateNode(['type' => 'bar', 'title' => 'Test Node Bar 3']),
      $this->drupalCreateNode(['type' => 'bar', 'title' => 'Test Node Bar 4']),
      $this->drupalCreateNode(['type' => 'baz', 'title' => 'Test Node Baz 5']),
      $this->drupalCreateNode(['type' => 'baz', 'title' => 'Test Node Baz 6']),
    ];

    $this->user = $this->drupalCreateUser(['access content']);
  }

}
